package de.hft.stuttgart.citydoctor2.healer.gui;

import java.io.IOException;

import de.hft.stuttgart.citydoctor2.gui.CityDoctorController;
import de.hft.stuttgart.citydoctor2.gui.MainToolBar;
import de.hft.stuttgart.citydoctor2.gui.MainWindow;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.control.Button;
import javafx.scene.control.ToggleButton;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Priority;
import javafx.scene.shape.CullFace;

public class HealerToolbar {

	private HealerController controller;
	private HBox toolBar;

	@FXML
	private ToggleButton wireframeBtn;

	@FXML
	private ToggleButton cullingBtn;

	@FXML
	private ImageView cullingImage;

	@FXML
	private ImageView wireframeImage;

	@FXML
	private HBox spacer;

	@FXML
	private Button saveBtn;

	@FXML
	private ImageView saveImage;

	@FXML
	private Button simplyBtn;

	@FXML
	private ImageView simplyImageView;

	private CityDoctorController cdController;

	public HealerToolbar(HealerController controller, MainWindow mainWindow) throws IOException {
		this.controller = controller;
		cdController = mainWindow.getController();
		FXMLLoader loader = new FXMLLoader(getClass().getResource("healerToolbar.fxml"));
		loader.setController(this);
		toolBar = loader.load();
	}

	public void initialize() {
		HBox.setHgrow(spacer, Priority.ALWAYS);
		cullingImage.setImage(new Image(MainToolBar.class.getResourceAsStream("icons/Culling.png")));
		wireframeImage.setImage(new Image(MainToolBar.class.getResourceAsStream("icons/wireframe32x32.png")));
		simplyImageView.setImage(new Image(HealerToolbar.class.getResourceAsStream("autopro32x32.png")));
		wireframeBtn.selectedProperty().addListener((obs, oldV, newV) -> controller.setWireframe(newV));
		cullingBtn.selectedProperty().addListener((obs, oldV, newV) -> {
			if (Boolean.TRUE.equals(newV)) {
				controller.setCulling(CullFace.BACK);
			} else {
				controller.setCulling(CullFace.NONE);
			}
		});
		saveBtn.setOnAction(ae -> cdController.askAndSave());
		saveBtn.setDisable(true);
		saveImage.setImage(new Image(MainWindow.class.getResourceAsStream("icons/save.png")));
		simplyBtn.setOnAction(ae -> controller.showSimplyfication());
	}

	public HBox getToolBar() {
		return toolBar;
	}

	public Button getSaveBtn() {
		return saveBtn;
	}

}
